.. symfit documentation master file, created by
   sphinx-quickstart on Thu Nov 27 13:46:41 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to symfit's documentation!
==================================

Contents:

.. toctree::
    :maxdepth: 2

    intro
    installation
    tutorial
    fitting_types
    style_guide
    technical_notes
    dependencies
    module_docs



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

